# Mocodo Syntax

Syntax highlighting support for Mocodo.

![Mocodo text source](doc/syntax_screenshot.png)

Mocodo is a tool for designing and teaching relational databases. It is based on the French-flavored Entity-Relationship model (aka Merise).

![Mocodo text source](doc/readme_1.png)

## Contributing
Bug reports and pull requests are welcome on GitHub at https://github.com/laowantong/mocodo/.

## License
MIT.

## Release Notes

### 1.0.5 -> 1.0.6

Update for Mocodo 4.0.5.

### 1.0.2

Add support for Mocodo 4.0's invisible boxes.

### 1.0.1

Don't regard a mix of empty and non-empty entity attributes as an error.

### 1.0.0

Improve color consistency between [Mocodo online](https://mocodo.net) and VS-Code's "Light+" or "Light Modern" themes.

### 0.0.2 -> 0.0.5

Fix packaging problems.

### 0.0.1

Initial release.

## For more information

* [Mocodo online](https://mocodo.net)
* [Github](https://github.com/laowantong/mocodo/)
* [Documentation](https://rawgit.com/laowantong/mocodo/master/doc/fr_refman.html)
